@@ -535,7 +535,7 @@ class Resource:
         self.create(wait=wait)
         return self
 
-    def clean_up(self, wait: bool = True) -> None:
+    def clean_up(self, wait: bool = True) -> bool:
         """
         For debug, export SKIP_RESOURCE_TEARDOWN to skip resource teardown.
         Spaces are important in the export dict
@@ -543,6 +543,9 @@ class Resource:
         Args:
             wait (bool, optional): Wait for resource deletion. Defaults to True.
 
+        Returns:
+            bool: True if resource was deleted else False.
+
         Examples:
             To skip teardown of all resources by kind:
                 export SKIP_RESOURCE_TEARDOWN="{Pod: {}}"
@@ -567,9 +570,9 @@ class Resource:
             self.logger.warning(
                 f"Skip resource {self.kind} {self.name} teardown. Got {_export_str}={skip_resource_teardown}"
             )
-            return
+            return False
 
-        self.delete(wait=wait, timeout=self.delete_timeout)
+        return self.delete(wait=wait, timeout=self.delete_timeout)
 
     @classmethod
     def _prepare_resources(
@@ -791,7 +794,7 @@ class Resource:
             if wait:
                 self.client_wait_deleted(timeout=timeout)
 
-        except NotFoundError:
+        except (NotFoundError, TimeoutExpiredError):
             return False
 
         return True
